@@ -36,12 +36,12 @@ describe 'openstack_extras::repo::redhat::redhat' do
 
     context 'with default parameters' do
       let :params do
-        default_params
+        {}
       end
 
       it { should contain_yumrepo('rdo-release').with(
-        :baseurl    => "http://mirror.centos.org/centos/7/cloud/$basearch/openstack-train/",
-        :descr      => 'OpenStack Train Repository',
+        :baseurl    => "http://mirror.centos.org/centos/7/cloud/$basearch/openstack-ussuri/",
+        :descr      => 'OpenStack Ussuri Repository',
         :gpgkey     => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud',
         :enabled    => '1',
         :gpgcheck   => '1',
@@ -69,33 +69,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :unless    => '/usr/bin/rpm -qa | /usr/bin/grep -q yum-plugin-priorities',
       ) }
 
-      # 'metalink' property is supported from Puppet 3.5
-      if Puppet.version.to_f >= 3.5
-        it { should contain_yumrepo('epel').with(
-          :metalink       => "https://mirrors.fedoraproject.org/metalink?repo=epel-7&arch=\$basearch",
-          :descr          => 'Extra Packages for Enterprise Linux 7 - $basearch',
-          :gpgkey         => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-7',
-          :failovermethod => 'priority',
-          :enabled        => '1',
-          :gpgcheck       => '1',
-          :mirrorlist     => 'absent',
-          :require        => 'Anchor[openstack_extras_redhat]',
-          :notify         => 'Exec[yum_refresh]'
-        )}
-      else
-        it { should contain_yumrepo('epel').with(
-          :baseurl        => "https://download.fedoraproject.org/pub/epel/7/\$basearch",
-          :descr          => 'Extra Packages for Enterprise Linux 7 - $basearch',
-          :gpgkey         => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-7',
-          :failovermethod => 'priority',
-          :enabled        => '1',
-          :gpgcheck       => '1',
-          :mirrorlist     => 'absent',
-          :require        => 'Anchor[openstack_extras_redhat]',
-          :notify         => 'Exec[yum_refresh]'
-        )}
-      end
-
       it { should contain_file('/etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Cloud').with(
         :source => 'puppet:///modules/openstack_extras/RPM-GPG-KEY-CentOS-SIG-Cloud',
         :owner  => 'root',
@@ -111,6 +84,37 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :mode   => '0644',
         :before => 'Anchor[openstack_extras_redhat]'
       )}
+
+      it { should_not contain_yumrepo('epel') }
+    end
+
+    context 'with major release 8 or later and virt repo enabled' do
+      let :params do
+        default_params.merge!( :manage_virt => true )
+      end
+
+      before do
+        facts.merge!( :os => {'release' => {'major' => 8}} )
+      end
+
+      it { should contain_yumrepo('rdo-qemu-ev').with(
+        :baseurl    => "http://mirror.centos.org/centos/8/virt/$basearch/advanced-virtualization/",
+        :descr      => 'RDO CentOS-8 - QEMU EV',
+        :gpgkey     => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-CentOS-SIG-Virtualization',
+        :enabled    => '1',
+        :gpgcheck   => '1',
+        :mirrorlist => 'absent',
+        :require    => 'Anchor[openstack_extras_redhat]',
+        :notify     => 'Exec[yum_refresh]'
+      )}
+    end
+
+    context 'with major release 8' do
+      before do
+        facts.merge!( :os => {'release' => {'major' => 8}} )
+      end
+
+      it { should_not contain_exec('installing_yum-plugin-priorities') }
     end
 
     context 'with overridden release' do
@@ -167,7 +171,6 @@ describe 'openstack_extras::repo::redhat::redhat' do
         :require    => 'Anchor[openstack_extras_redhat]',
         :notify     => 'Exec[yum_refresh]'
       )}
-
     end
 
     context 'with overridden repo default' do
@@ -200,6 +203,24 @@ describe 'openstack_extras::repo::redhat::redhat' do
       )}
     end
 
+    context 'with epel management enabled' do
+      let :params do
+        default_params.merge!({ :manage_epel => true })
+      end
+
+      it { should contain_yumrepo('epel').with(
+        :metalink       => "https://mirrors.fedoraproject.org/metalink?repo=epel-7&arch=\$basearch",
+        :descr          => 'Extra Packages for Enterprise Linux 7 - $basearch',
+        :gpgkey         => 'file:///etc/pki/rpm-gpg/RPM-GPG-KEY-EPEL-7',
+        :failovermethod => 'priority',
+        :enabled        => '1',
+        :gpgcheck       => '1',
+        :mirrorlist     => 'absent',
+        :require        => 'Anchor[openstack_extras_redhat]',
+        :notify         => 'Exec[yum_refresh]'
+      )}
+    end
+
     context 'with epel management disabled' do
       let :params do
         default_params.merge!({ :manage_epel => false })
@@ -231,6 +252,26 @@ describe 'openstack_extras::repo::redhat::redhat' do
 
       it { should_not contain_exec('installing_yum-plugin-priorities') }
     end
+
+    context 'with repo_source_hash' do
+      let :params do
+        default_params.merge!({
+          :repo_source_hash => {
+            'delorean.repo'      => 'https://trunk.rdoproject.org/centos8-master/puppet-passed-ci/delorean.repo',
+            'delorean-deps.repo' => 'https://trunk.rdoproject.org/centos8-master/delorean-deps.repo'}})
+      end
+
+      it {
+        should contain_file('delorean.repo').with(
+          :path   => '/etc/yum.repos.d/delorean.repo',
+          :source => 'https://trunk.rdoproject.org/centos8-master/puppet-passed-ci/delorean.repo'
+        )
+        should contain_file('delorean-deps.repo').with(
+          :path   => '/etc/yum.repos.d/delorean-deps.repo',
+          :source => 'https://trunk.rdoproject.org/centos8-master/delorean-deps.repo'
+        )
+      }
+    end
   end
 
   on_supported_os({
@@ -241,6 +282,7 @@ describe 'openstack_extras::repo::redhat::redhat' do
         facts.merge!(OSDefaults.get_facts({ :operatingsystem           => 'RedHat',
                                             :operatingsystemrelease    => '7.1',
                                             :operatingsystemmajrelease => '7',
+                                            :os                        => {'release' => {'major' => '7'}},
                                             :puppetversion             => Puppet.version }))
       end
 
